import * as React from 'react';
import { useDeepCompareEffect } from 'use-deep-compare';

const useClickOutside = (refs, onClickOutside) => {
  const [isActive, setActive] = React.useState(false);
  useDeepCompareEffect(() => {
    const mousedown = e => {
      const test = refs.map(ref => {
        return ref.current !== null && !ref.current.contains(e.target);
      });

      if (test.every(Boolean)) {
        setActive(true);
        onClickOutside(e);
      }
    };

    const mouseup = e => {
      const test = refs.map(ref => {
        return ref.current !== null && !ref.current.contains(e.target);
      });

      if (test.every(Boolean)) {
        setActive(false);
      }
    };

    document.addEventListener('mousedown', mousedown);
    document.addEventListener('mouseup', mouseup);
    return () => {
      document.removeEventListener('mousedown', mousedown);
      document.removeEventListener('mouseup', mouseup);
    };
  }, [refs, onClickOutside]);
  return [isActive];
};

export default useClickOutside;